package com.ruoyi.web.bst;

import java.util.List;

import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import com.ruoyi.bst.taskSubmit.domain.TaskSubmitQuery;
import com.ruoyi.bst.taskSubmit.domain.TaskSubmitVO;
import com.ruoyi.bst.taskSubmit.domain.dto.TaskSubmitVerifyDTO;
import com.ruoyi.bst.taskSubmit.service.TaskSubmitService;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;


/**
 * 任务提交记录Controller
 *
 * @author ruoyi
 * @date 2025-02-08
 */
@RestController
@RequestMapping("/bst/taskSubmit")
public class TaskSubmitController extends BaseController
{
    @Autowired
    private TaskSubmitService taskSubmitService;

    /**
     * 查询任务提交记录列表
     */
    @PreAuthorize("@ss.hasPermi('bst:taskSubmit:list')")
    @GetMapping("/list")
    public TableDataInfo list(TaskSubmitQuery query)
    {
        startPage();
        startOrderBy();
        List<TaskSubmitVO> list = taskSubmitService.selectTaskSubmitList(query);
        return getDataTable(list);
    }

    /**
     * 导出任务提交记录列表
     */
    @PreAuthorize("@ss.hasPermi('bst:taskSubmit:export')")
    @Log(title = "任务提交记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TaskSubmitQuery query)
    {
        List<TaskSubmitVO> list = taskSubmitService.selectTaskSubmitList(query);
        ExcelUtil<TaskSubmitVO> util = new ExcelUtil<TaskSubmitVO>(TaskSubmitVO.class);
        util.exportExcel(response, list, "任务提交记录数据");
    }

    /**
     * 获取任务提交记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('bst:taskSubmit:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(taskSubmitService.selectTaskSubmitById(id));
    }

    /**
     * 审核提交记录
     */
    @PreAuthorize("@ss.hasPermi('bst:taskSubmit:verify')")
    @Log(title = "任务提交记录", businessType = BusinessType.UPDATE)
    @PutMapping("/verify")
    public AjaxResult verify(@RequestBody @Validated TaskSubmitVerifyDTO dto){
        return toAjax(taskSubmitService.verify(dto));
    }
}
